@@ -3,7 +3,7 @@ from __future__ import unicode_literals
 import sqlite3
 import unittest
 
-from mopidy.models import Artist, Album, Track
+from mopidy.models import Ref, Artist, Album, Track
 from mopidy_local_sqlite import schema
 
 DBPATH = ':memory:'
@@ -16,19 +16,20 @@ class SchemaTest(unittest.TestCase):
     ]
     albums = [
         Album(uri='local:album:0', name='album #0'),
-        Album(uri='local:album:1', name='album #1', artists=[artists[0]])
+        Album(uri='local:album:1', name='album #1', artists=[artists[0]]),
+        Album(uri='local:album:2', name='album #2', artists=[artists[1]])
     ]
     tracks = [
         Track(uri='local:track:0', name='track #0'),
         Track(uri='local:track:1', name='track #1', artists=[artists[0]]),
         Track(uri='local:track:2', name='track #2', album=albums[0]),
-        Track(uri='local:track:3', name='track #3', album=albums[1],
-              artists=[artists[1]]),
+        Track(uri='local:track:3', name='track #3', album=albums[1]),
+        Track(uri='local:track:4', name='track #4', album=albums[2],
+              composers=[artists[0]], performers=[artists[0]])
     ]
 
     def setUp(self):
         self.connection = sqlite3.connect(DBPATH, factory=schema.Connection)
-        self.connection.execute('PRAGMA foreign_keys = ON')
         schema.load(self.connection)
         for track in self.tracks:
             schema.insert_track(self.connection, track)
@@ -40,12 +41,12 @@ class SchemaTest(unittest.TestCase):
     def test_create(self):
         count = schema.count_tracks(self.connection)
         self.assertEqual(len(self.tracks), count)
-        tracks = list(schema.iter_tracks(self.connection))
+        tracks = list(schema.tracks(self.connection))
         self.assertEqual(len(self.tracks), len(tracks))
 
     def test_lookup(self):
         for track in self.tracks:
-            result = schema.get_track(self.connection, track.uri)
+            result = schema.lookup(self.connection, track.uri)
             # cannot use result == track here...
             self.assertEqual(track.uri, result.uri)
             self.assertEqual(track.name, result.name)
@@ -63,7 +64,7 @@ class SchemaTest(unittest.TestCase):
                 []
             ),
             (
-                [self.tracks[1].uri, self.tracks[3].uri],
+                [self.tracks[1].uri, self.tracks[3].uri, self.tracks[4].uri],
                 [('any', self.artists[0].name)],
                 []
             ),
@@ -101,7 +102,7 @@ class SchemaTest(unittest.TestCase):
                 []
             ),
             (
-                [self.tracks[1].uri],
+                [self.tracks[1].uri, self.tracks[3].uri],
                 [('track_name', 'track')],
                 [('artist', self.artists[0].uri)]
             ),
@@ -111,44 +112,67 @@ class SchemaTest(unittest.TestCase):
             self.assertItemsEqual(results, map(lambda t: t.uri, tracks))
 
     def test_browse_artists(self):
-        result = schema.browse_artists(self.connection)
-        self.assertEqual(len(self.artists), len(result))
+        with self.connection as c:
+            result = schema.browse(c, Ref.ARTIST)
+            self.assertEqual(len(self.artists), len(result))
 
-        result = schema.browse_artists(self.connection, self.artists[0].uri)
-        self.assertEqual(2, len(result))  # one album and one track w/o album
+            result = schema.browse(c, Ref.ARTIST, role='artist')
+            self.assertEqual(2, len(result))
 
-        result = schema.browse_artists(self.connection, self.artists[1].uri)
-        self.assertEqual(1, len(result))
+            result = schema.browse(c, Ref.ARTIST, role='composer')
+            self.assertEqual(1, len(result))
+
+            result = schema.browse(c, Ref.ARTIST, role='performer')
+            self.assertEqual(1, len(result))
 
     def test_browse_albums(self):
-        result = schema.browse_albums(self.connection)
-        self.assertEqual(len(self.albums), len(result))
+        with self.connection as c:
+            result = schema.browse(c, Ref.ALBUM)
+            self.assertEqual(len(self.albums), len(result))
 
-        result = schema.browse_albums(self.connection, self.albums[0].uri)
-        self.assertEqual(1, len(result))
+            result = schema.browse(c, Ref.ALBUM, artist=self.artists[0].uri)
+            self.assertEqual(1, len(result))
 
     def test_browse_tracks(self):
-        result = schema.browse_tracks(self.connection)
-        self.assertEqual(len(self.tracks), len(result))
+        with self.connection as c:
+            result = schema.browse(c, Ref.TRACK)
+            self.assertEqual(len(self.tracks), len(result))
+
+            result = schema.browse(c, Ref.TRACK, artist=self.artists[0].uri)
+            self.assertEqual(2, len(result))
+
+            result = schema.browse(c, Ref.TRACK, artist=self.artists[1].uri)
+            self.assertEqual(1, len(result))
+
+            result = schema.browse(c, Ref.TRACK, composer=self.artists[0].uri)
+            self.assertEqual(1, len(result))
+
+            result = schema.browse(c, Ref.TRACK, performer=self.artists[0].uri)
+            self.assertEqual(1, len(result))
 
     def test_delete(self):
         c = self.connection
         schema.delete_track(c, self.tracks[0].uri)
         schema.cleanup(c)
-        self.assertEqual(2, len(c.execute('SELECT * FROM album').fetchall()))
+        self.assertEqual(3, len(c.execute('SELECT * FROM album').fetchall()))
         self.assertEqual(2, len(c.execute('SELECT * FROM artist').fetchall()))
 
         schema.delete_track(c, self.tracks[1].uri)
         schema.cleanup(c)
-        self.assertEqual(2, len(c.execute('SELECT * FROM album').fetchall()))
+        self.assertEqual(3, len(c.execute('SELECT * FROM album').fetchall()))
         self.assertEqual(2, len(c.execute('SELECT * FROM artist').fetchall()))
 
         schema.delete_track(c, self.tracks[2].uri)
         schema.cleanup(c)
-        self.assertEqual(1, len(c.execute('SELECT * FROM album').fetchall()))
+        self.assertEqual(2, len(c.execute('SELECT * FROM album').fetchall()))
         self.assertEqual(2, len(c.execute('SELECT * FROM artist').fetchall()))
 
         schema.delete_track(c, self.tracks[3].uri)
         schema.cleanup(c)
+        self.assertEqual(1, len(c.execute('SELECT * FROM album').fetchall()))
+        self.assertEqual(2, len(c.execute('SELECT * FROM artist').fetchall()))
+
+        schema.delete_track(c, self.tracks[4].uri)
+        schema.cleanup(c)
         self.assertEqual(0, len(c.execute('SELECT * FROM album').fetchall()))
         self.assertEqual(0, len(c.execute('SELECT * FROM artist').fetchall()))
